package luke;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Properties;

/**
 *
 * Handle read/write of fixed size string list to property file; unique values only 
 */
public class PersistentStringList {
	private List _list = new ArrayList();
	private File _file = null;
	private String _name = "";
	private int _size = 0;
	
	public PersistentStringList( File file, String name, int size  ) {
		_name = name;
		_file = file;
		_size = size;

		load();
	}
	
	private void load() {
		try {
			Properties props = new Properties();
			if( _file.exists() ) {
				props.load(new FileInputStream(_file));
				for( int i = 0; i < _size; i++ ) {
					String str = props.getProperty(_name+i);
					if( str != null && !str.trim().equals("")) {
						_list.add(str.trim());
					}
				}
			}
		} catch( FileNotFoundException e ) {
			// ignore		
		} catch (IOException e) {
			// ignore	
		}				
	}

	private void save() {
		try {
			
			Properties props = new Properties();
			if( _file.exists() ) {
				props.load(new FileInputStream(_file));
			}
			for( int i = 0; i < _list.size(); i++ ) {
				String str = (String)_list.get(i);
				if( str != null && !str.equals("")) {
					props.put(_name+i, str);	
				}
			}
			props.store( new FileOutputStream(_file),"");
		} catch( FileNotFoundException e ) {
			// ignore		
		} catch (IOException e) {
			// ignore	
		}				
	}

	public Iterator iterator() {
		return _list.iterator();
	}

	public void add( String string ) {
		if( _list.indexOf(string) == -1 ) {
			_list.add( string );
			pack();
			save();
		}
	}
	
	private void pack() {
		if( _list.size() > _size ) {
			_list = _list.subList( _list.size() - _size, _size ); 
		}		
	}
}
